package utils

import (
	"fmt"
	"net/mail"
	"os"
	"strings"
)

func IsEmail(email string) bool {
	_, err := mail.ParseAddress(email)
	return err == nil
}

// Convert a string of USB devices of the form "1fc9:001d,067b:2303"
// into a slice of string where each element is a string of the form "1fc9:001d".
// Returns an empty slice if the input string is "none".
func Str2UsbDevices(s string) []string {
	usbDevs := []string{}
	if s != "none" {
		devs := strings.Split(s, ",") // Extracts USB devices
		for _, dev := range devs {
			usbDevs = append(usbDevs, dev)
		}
	}
	return usbDevs
}

// Returns the content of file as a string
func FileToString(file string) (string, error) {
	content, err := os.ReadFile(file)
	if err != nil {
		return "", err
	}
	return string(content), nil
}

// Removes an element from a string array at a given index
func RemoveArgAtIndex(slice []string, index int) []string {
	return append(slice[:index], slice[index+1:]...)
}

// TODO: better way of appending a portable "new line" to a string
func AppendNewLine(s string) string {
	var newLine string
	newLine = fmt.Sprintln(newLine, "")
	return s + newLine
}
